import * as React from 'react';

/**
 * Supported `Component` nodes.
 */
declare const NODES: readonly ["a", "blockquote", "button", "div", "em", "fieldset", "footer", "form", "h1", "h2", "h3", "h4", "h5", "h6", "header", "img", "input", "label", "main", "small", "strong", "optgroup", "option", "output", "p", "select", "span", "textarea"];
/**
 * Type to define generic `Component` props.
 */
type IComponentProps = {
    asChild?: boolean;
    twx?: (args: unknown) => string;
};
/**
 * Type to define the supported `Component` nodes.
 */
type Components = {
    [E in (typeof NODES)[number]]: IForwardRefComponent<E>;
};
/**
 * Type to define `Component` props with the 'ref' prop.
 */
type ComponentPropsWithRef<E extends React.ElementType> = React.ComponentPropsWithRef<E> & IComponentProps;
/**
 * Type to define `Component` as a forwarded ref component.
 */
interface IForwardRefComponent<E extends React.ElementType> extends React.ForwardRefExoticComponent<ComponentPropsWithRef<E>> {
}
/**
 * `Component` - a higher-order component that extends standard html tags.
 */
declare const Component: Components;

export { Component, type ComponentPropsWithRef };
